@@ -14,9 +14,9 @@
 from __future__ import absolute_import
 
 from flask import Flask
-from flask_sqlalchemy import SQLAlchemy
-from flaskext.testing import TestCase
-import flask_whooshalchemy
+from flask.ext.sqlalchemy import SQLAlchemy
+from flask.ext.testing import TestCase
+import flask.ext.whooshalchemy as wa
 
 import datetime
 import os
@@ -39,6 +39,11 @@ class BlogishBlob(object):
         return '{0}(title={1})'.format(self.__class__.__name__, self.title)
 
 
+def _after_flush(app, changes):
+    from sqlalchemy.orm import EXT_CONTINUE
+    return EXT_CONTINUE
+
+
 class ObjectA(db.Model, BlogishBlob):
     __tablename__ = 'objectA'
     __searchable__ = ['title', 'content', 'blurb']
@@ -46,7 +51,7 @@ class ObjectA(db.Model, BlogishBlob):
 
 class ObjectB(db.Model, BlogishBlob):
     __tablename__ = 'objectB'
-    __searchable__ = ['title', 'content', 'content'] # dup intentional
+    __searchable__ = ['title', 'content', 'content']  # dup intentional
 
 
 class ObjectC(db.Model, BlogishBlob):
@@ -54,10 +59,9 @@ class ObjectC(db.Model, BlogishBlob):
     __searchable__ = ['title', 'field_that_doesnt_exist']
 
 
-
 class Tests(TestCase):
-    DATABASE_URL='sqlite://'
-    TESTING=True
+    DATABASE_URL = 'sqlite://'
+    TESTING = True
 
     def create_app(self):
         tmp_dir = tempfile.mkdtemp()
@@ -76,12 +80,25 @@ class Tests(TestCase):
         try:
             shutil.rmtree(self.app.config['WHOOSH_BASE'])
         except OSError, e:
-            if e.errno != 2: # code 2 - no such file or directory
+            if e.errno != 2:  # code 2 - no such file or directory
                 raise
 
-        db.session.remove()
         db.drop_all()
 
+    def test_flask_fail(self):
+        # XXX This fails due to a bug in Flask-SQLAlchemy that affects
+        # Flask-WhooshAlchemy. I submitted a pull request with a fix that is
+        # pending.
+
+        from flask.ext.sqlalchemy import before_models_committed, models_committed
+        
+        before_models_committed.connect(_after_flush)
+        models_committed.connect(_after_flush)
+        db.session.add(ObjectB(title=u'my title', content=u'hello world'))
+        db.session.add(ObjectA(title=u'a title', content=u'hello world'))
+        db.session.flush()
+        db.session.commit()
+
     def test_all(self):
         title1 = u'a slightly long title'
         title2 = u'another title'
